@@ -1,13 +1,11 @@
 import logging
 from abc import ABC, abstractmethod
-from enum import Enum
 from itertools import count
 from typing import Any, Final, Iterable, Sequence, Type, TypeVar
 
 import msgspec
 
 from .api_types import (
-    BaseTelegram,
     BotCommand,
     BotCommandScope,
     Chat,
@@ -60,18 +58,9 @@ __all__ = ("ParamType", "ApiMethods")
 api_logger: Final[logging.Logger] = logging.getLogger("aiotgbot.api")
 
 
-_ItemType = BaseTelegram | str | int | Enum
-
-
 ParamType = int | float | str | InputFile | None
 
 
-# TODO: remove
-def _enum_to_str(item: Enum | None) -> str | None:
-    assert item is None or isinstance(item.value, str)
-    return item.value if item is not None else None
-
-
 def _encode_json(obj: Any) -> str | None:
     if obj is not None:
         return msgspec.json.encode(obj).decode()
@@ -274,7 +263,7 @@ class ApiMethods(ABC):
     async def send_photo(
         self,
         chat_id: int | str,
-        photo: int | str,
+        photo: InputFile | str,
         caption: str | None = None,
         parse_mode: ParseMode | None = None,
         caption_entities: Sequence[MessageEntity] | None = None,
@@ -292,7 +281,7 @@ class ApiMethods(ABC):
             Message,
             photo=photo,
             caption=caption,
-            parse_mode=_enum_to_str(parse_mode),
+            parse_mode=parse_mode,
             caption_entities=_encode_json(caption_entities),
             disable_notification=disable_notification,
             protect_content=protect_content,
@@ -304,7 +293,7 @@ class ApiMethods(ABC):
     async def send_audio(
         self,
         chat_id: int | str,
-        audio: int | str,
+        audio: InputFile | str,
         caption: str | None = None,
         parse_mode: ParseMode | None = None,
         caption_entities: Sequence[MessageEntity] | None = None,
@@ -326,7 +315,7 @@ class ApiMethods(ABC):
             Message,
             audio=audio,
             caption=caption,
-            parse_mode=_enum_to_str(parse_mode),
+            parse_mode=parse_mode,
             caption_entities=_encode_json(caption_entities),
             disable_notification=disable_notification,
             protect_content=protect_content,
@@ -342,7 +331,7 @@ class ApiMethods(ABC):
     async def send_document(
         self,
         chat_id: int | str,
-        document: int | str,
+        document: InputFile | str,
         thumb: InputFile | str | None = None,
         caption: str | None = None,
         parse_mode: ParseMode | None = None,
@@ -366,7 +355,7 @@ class ApiMethods(ABC):
             document=document,
             thumb=thumb,
             caption=caption,
-            parse_mode=_enum_to_str(parse_mode),
+            parse_mode=parse_mode,
             caption_entities=_encode_json(caption_entities),
             disable_content_type_detection=disable_content_type_detection,
             disable_notification=disable_notification,
@@ -382,7 +371,7 @@ class ApiMethods(ABC):
     async def send_video(
         self,
         chat_id: int | str,
-        video: int | str,
+        video: InputFile | str,
         duration: int | None = None,
         width: int | None = None,
         height: int | None = None,
@@ -409,7 +398,7 @@ class ApiMethods(ABC):
             height=height,
             thumb=thumb,
             caption=caption,
-            parse_mode=_enum_to_str(parse_mode),
+            parse_mode=parse_mode,
             caption_entities=_encode_json(caption_entities),
             supports_streaming=supports_streaming,
             disable_notification=disable_notification,
@@ -422,7 +411,7 @@ class ApiMethods(ABC):
     async def send_animation(
         self,
         chat_id: int | str,
-        animation: int | str,
+        animation: InputFile | str,
         duration: int | None = None,
         width: int | None = None,
         height: int | None = None,
@@ -448,7 +437,7 @@ class ApiMethods(ABC):
             height=height,
             thumb=thumb,
             caption=caption,
-            parse_mode=_enum_to_str(parse_mode),
+            parse_mode=parse_mode,
             caption_entities=_encode_json(caption_entities),
             disable_notification=disable_notification,
             protect_content=protect_content,
@@ -460,7 +449,7 @@ class ApiMethods(ABC):
     async def send_voice(
         self,
         chat_id: int | str,
-        voice: int | str,
+        voice: InputFile | str,
         caption: str | None = None,
         parse_mode: ParseMode | None = None,
         caption_entities: Sequence[MessageEntity] | None = None,
@@ -479,7 +468,7 @@ class ApiMethods(ABC):
             Message,
             voice=voice,
             caption=caption,
-            parse_mode=_enum_to_str(parse_mode),
+            parse_mode=parse_mode,
             caption_entities=_encode_json(caption_entities),
             duration=duration,
             disable_notification=disable_notification,
@@ -492,7 +481,7 @@ class ApiMethods(ABC):
     async def send_video_note(
         self,
         chat_id: int | str,
-        video_note: int | str,
+        video_note: InputFile | str,
         duration: int | None = None,
         length: int | None = None,
         thumb: InputFile | str | None = None,
@@ -613,7 +602,7 @@ class ApiMethods(ABC):
         return await self._request(
             RequestMethod.POST,
             "editMessageLiveLocation",
-            Message | bool,  # type: ignore
+            Message | bool,  # type: ignore # TODO
             chat_id=chat_id,
             message_id=message_id,
             inline_message_id=inline_message_id,
@@ -636,7 +625,7 @@ class ApiMethods(ABC):
         return await self._request(
             RequestMethod.POST,
             "stopMessageLiveLocation",
-            Message | bool,  # type: ignore
+            Message | bool,  # type: ignore # TODO
             chat_id=chat_id,
             message_id=message_id,
             inline_message_id=inline_message_id,
@@ -769,7 +758,7 @@ class ApiMethods(ABC):
             "sendDice",
             chat_id,
             Message,
-            emoji=_enum_to_str(emoji),
+            emoji=emoji,
             disable_notification=disable_notification,
             protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
@@ -1328,12 +1317,12 @@ class ApiMethods(ABC):
         return await self._request(
             RequestMethod.POST,
             "editMessageText",
-            Message | bool,  # type: ignore
+            Message | bool,  # type: ignore # TODO
             chat_id=chat_id,
             message_id=message_id,
             inline_message_id=inline_message_id,
             text=text,
-            parse_mode=_enum_to_str(parse_mode),
+            parse_mode=parse_mode,
             entities=_encode_json(entities),
             disable_web_page_preview=disable_web_page_preview,
             reply_markup=_encode_json(reply_markup),
@@ -1366,12 +1355,12 @@ class ApiMethods(ABC):
         return await self._request(
             RequestMethod.POST,
             "editMessageCaption",
-            Message | bool,  # type: ignore
+            Message | bool,  # type: ignore # TODO
             chat_id=chat_id,
             message_id=message_id,
             inline_message_id=inline_message_id,
             caption=caption,
-            parse_mode=_enum_to_str(parse_mode),
+            parse_mode=parse_mode,
             caption_entities=_encode_json(caption_entities),
             reply_markup=_encode_json(reply_markup),
         )
@@ -1408,7 +1397,7 @@ class ApiMethods(ABC):
         return await self._request(
             RequestMethod.POST,
             "editMessageMedia",
-            Message | bool,  # type: ignore
+            Message | bool,  # type: ignore # TODO
             chat_id=chat_id,
             message_id=message_id,
             inline_message_id=inline_message_id,
@@ -1441,7 +1430,7 @@ class ApiMethods(ABC):
         return await self._request(
             RequestMethod.POST,
             "editMessageReplyMarkup",
-            Message | bool,  # type: ignore
+            Message | bool,  # type: ignore # TODO
             chat_id=chat_id,
             message_id=message_id,
             inline_message_id=inline_message_id,
@@ -1566,8 +1555,8 @@ class ApiMethods(ABC):
             title=title,
             emojis=emojis,
             stickers=_encode_json(attached_media),
-            sticker_format=_enum_to_str(sticker_format),
-            sticker_type=_enum_to_str(sticker_type),
+            sticker_format=sticker_format,
+            sticker_type=sticker_type,
             needs_repainting=needs_repainting,
         )
 
@@ -1873,7 +1862,7 @@ class ApiMethods(ABC):
         return await self._request(
             RequestMethod.POST,
             "setGameScore",
-            Message | bool,  # type: ignore
+            Message | bool,  # type: ignore # TODO
             user_id=user_id,
             score=score,
             force=force,
