@@ -1,18 +1,19 @@
-from typing import Any, AsyncIterator, Dict, Final, Tuple
+from typing import Any, AsyncIterator, Final
 
 from aiotgbot.storage import Json, StorageProtocol
 
-__all__ = ('MemoryStorage',)
+__all__ = ("MemoryStorage",)
 
 
 class MemoryStorage(StorageProtocol):
-
     def __init__(self) -> None:
-        self._data: Final[Dict[str, Any]] = {}
+        self._data: Final[dict[str, Any]] = {}
 
-    async def connect(self) -> None: ...
+    async def connect(self) -> None:
+        ...
 
-    async def close(self) -> None: ...
+    async def close(self) -> None:
+        ...
 
     async def set(self, key: str, value: Json = None) -> None:
         self._data[key] = value
@@ -24,8 +25,8 @@ class MemoryStorage(StorageProtocol):
         self._data.pop(key)
 
     async def iterate(
-        self, prefix: str = ''
-    ) -> AsyncIterator[Tuple[str, Json]]:
+        self, prefix: str = ""
+    ) -> AsyncIterator[tuple[str, Json]]:
         for key, value in self._data.items():
             if key.startswith(prefix):
                 yield key, value
